<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>API</name>
    <message>
        <source>Please log in with your Deepin ID.</source>
        <translation>Deepin İD ilə daxil olun.</translation>
    </message>
    <message>
        <source>You need to log in to proceed with the subsequent operations.</source>
        <translation>Sonrakı əmələiyyatlara davam etmək üçün daxil olmalısınız.</translation>
    </message>
</context>
<context>
    <name>APIProxy</name>
    <message>
        <source>You have been making too many requests, Please try again later.</source>
        <translation>Siz həddindən çox sorğu etmisiniz. Lütfən, sonra yenidən cəhd edin.</translation>
    </message>
    <message>
        <source>You need to login to proceed with the subsequent operations.</source>
        <translation>Sonrakı əmələiyyatlara davam etmək üçün daxil olmalısınız.</translation>
    </message>
    <message>
        <source>Network error, please try later.</source>
        <translation>Şəbəkə xətası, sonra yenidən cəhd edin.</translation>
    </message>
</context>
<context>
    <name>AccountButton</name>
    <message>
        <source>Unlogged</source>
        <translation>Hesabdan çıxmış</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Seçilmişlər</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Mənim rəylərim</translation>
    </message>
    <message>
        <source>Sign out</source>
        <translation>Çıxın</translation>
    </message>
    <message>
        <source>Sign in</source>
        <translation>Daxil olun</translation>
    </message>
</context>
<context>
    <name>Card</name>
    <message>
        <source>%1 views</source>
        <translation>%1 baxış</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Təkliflər</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Seçilməmiş</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Seçilmiş</translation>
    </message>
    <message>
        <source>Cancel the urge</source>
        <translation>Bu istəyi ləğv edin</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>İstək</translation>
    </message>
</context>
<context>
    <name>Card1</name>
    <message>
        <source>Coming</source>
        <translation>Tezliklə</translation>
    </message>
</context>
<context>
    <name>Detail</name>
    <message>
        <source>Official response</source>
        <translation>Rəsmi cavab</translation>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Search</source>
        <translation>Axtarış</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tip:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Hamısını</translation>
    </message>
    <message>
        <source>Bug</source>
        <translation>Hata</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>SovgỨraqlar</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Versiyon:</translation>
    </message>
    <message>
        <source>Sort:</source>
        <translation>Sırala:</translation>
    </message>
    <message>
        <source>Newest</source>
        <translation>En son</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sevimli</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>Çoğald</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <source>Communication</source>
        <translation>Kommunikasiya</translation>
    </message>
    <message>
        <source>Discuss and share here</source>
        <translation>Burada müzakirə edin və paylaşın</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Xəta bidirişi</translation>
    </message>
    <message>
        <source>Report issues you found</source>
        <translation>Tapdığınız xıtaları bioldirin</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Təkliflər</translation>
    </message>
    <message>
        <source>Submit your suggestions</source>
        <translation>Təkliflərinizi bildirin</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>Mənbələr</translation>
    </message>
    <message>
        <source>Questionaire</source>
        <translation>Anket</translation>
    </message>
    <message>
        <source>Join US</source>
        <translation>Bizə qoşul</translation>
    </message>
    <message>
        <source>Internal Testing</source>
        <translation>Daxili sınama</translation>
    </message>
    <message>
        <source>Global Translation</source>
        <translation>Global Çeviri</translation>
    </message>
    <message>
        <source>Community News</source>
        <translation>Cəmiyytin xəbərləri</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <source>No more items</source>
        <translation>Başqa elementlər yoxdur</translation>
    </message>
    <message>
        <source>Messages</source>
        <translation>İsmarıclar</translation>
    </message>
    <message>
        <source>Questionaires</source>
        <translation>Anket</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <source>Launch at system startup</source>
        <translation>Sistem açılışı ilə birlikdə işə salmaq</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Haqında</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Çıxış</translation>
    </message>
    <message>
        <source>Deepin Home</source>
        <translation>Deepin Evi</translation>
    </message>
    <message>
        <source>Quick login to forums, submit suggestions, and report bugs.</source>
        <translation>Forumlara sürətli giriş, təkliflərin göndərilməsi və xəta bildirişləri.</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>No messages yet.</source>
        <translation>Hələlik heç bir ismarıc yoxdur.</translation>
    </message>
    <message>
        <source>%1 messages</source>
        <translation>%1 ismarıc var</translation>
    </message>
    <message>
        <source>Mark all as read</source>
        <translation>Hamısını oxunmuş kimi işarələ.</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <source>View more</source>
        <translation>Daha çox göstərmək</translation>
    </message>
</context>
<context>
    <name>Offline</name>
    <message>
        <source>Network error, please try later</source>
        <translation>Şəbəkə xətası, sonra yenidən cəhd edin</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Təzələ</translation>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <source>Deepin Home</source>
        <translation>Deepin Ev</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <source>No questionaires yet.</source>
        <translation>Hələlik heç bir anket yoxdur.</translation>
    </message>
    <message>
        <source>Expired on: %1</source>
        <translation>Bitmə vaxctı: %1</translation>
    </message>
    <message>
        <source>Fill In</source>
        <translation>Doldurun</translation>
    </message>
</context>
<context>
    <name>Status</name>
    <message>
        <source>Pending</source>
        <translation>Gözləyən</translation>
    </message>
    <message>
        <source>Reproducing</source>
        <translation>Çoxalma</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Təsdiq olunmuş</translation>
    </message>
    <message>
        <source>Replied</source>
        <translation>Cavab verilən</translation>
    </message>
    <message>
        <source>Resolved</source>
        <translation>Həll olunan</translation>
    </message>
    <message>
        <source>Evaluating</source>
        <translation>Qiymətləndirmə</translation>
    </message>
    <message>
        <source>Accepted</source>
        <translation>Qəbul edilmiş</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Tamamlanmış</translation>
    </message>
    <message>
        <source>The issue has not been processed and will not be displayed in the public listing.</source>
        <translation>Problem ələ alınmayıb və ümumu siyahıda göstərilməyəcək.</translation>
    </message>
    <message>
        <source>Currently unable to identify the cause; continuous monitoring and investigation are required.</source>
        <translation>Hal-hazırda səbəbi müəyyən etmək mümkün deyil, davamlı izləmə və araşdırma tələb olunur.</translation>
    </message>
    <message>
        <source>The issue has been reproduced and the root cause has been identified.</source>
        <translation>Problem təkrarlandı və səbəbin kökü müəyyən edilmişdir.</translation>
    </message>
    <message>
        <source>The issue is not a bug or of a different nature.</source>
        <translation>Problem bir xəta deyil və ya başqa xüsusiyyət daşımır.</translation>
    </message>
    <message>
        <source>The issue has been resolved and awaiting formal release</source>
        <translation>Problem həll olunub və rəsmi buraxılışı göslənilir</translation>
    </message>
    <message>
        <source>The requirement has not been processed and will not be displayed in the public listing</source>
        <translation>Tələb üzərində iş görülməyib və ümumi siyahıda göstərilməyəcək</translation>
    </message>
    <message>
        <source>The issue has been acknowledged and is being internally assessed</source>
        <translation>Problem nəzərdən keçirilib və daxili qiymətləndirmə aparılır</translation>
    </message>
    <message>
        <source>Included in the plans for a future release</source>
        <translation>Gələcək buraxılış planlarına daxil edilib</translation>
    </message>
    <message>
        <source>The requirement is either not accepted or unable to be addressed</source>
        <translation>Tələb ya qəbul edilməyib, ya da yerinə yetirilə bilməz</translation>
    </message>
    <message>
        <source>Development work is finished, awaiting formal release</source>
        <translation>Tərtibat işləri başa çatıb və rəsmi buraxılışı göslənilir</translation>
    </message>
</context>
<context>
    <name>Submit</name>
    <message>
        <source>Unable to add a screenshot.</source>
        <translation>Ekran şəkli əlavə etmək mümkün olmadı.</translation>
    </message>
    <message>
        <source>The image file size should be less than 1MB.</source>
        <translation>Şəkil faylının ölçüsü 1MB-dan az olmalıdır.</translation>
    </message>
    <message>
        <source>The image file format is not supported for uploading.</source>
        <translation>Yükləmək üçün şəklin fayl formatı dəstəklənmir.</translation>
    </message>
    <message>
        <source>[Current Status of the Product]: 
[Desired Product]: </source>
        <translation>[Məhsulun cari vəziyyəti]
[Arzuolunan məhsul]</translation>
    </message>
    <message>
        <source>[Preconditions]: 
[Reproducibility Steps]: 
[Expected Results]: 
[Actual Results]: </source>
        <translation>[Ön şərt]:
[Repreduksiya addımları]:
[Gözlənilən Nəticələr]:
[Aktual nəticələr]:</translation>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation>Rəy göndərin</translation>
    </message>
    <message>
        <source>Type：</source>
        <translation>Növ:</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Təkliflər</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Xəta bildirişi</translation>
    </message>
    <message>
        <source>Title：</source>
        <translation>Başlıq:</translation>
    </message>
    <message>
        <source>Please provide a brief description of your issue</source>
        <translation>Xahiş edirəm, problemləriniz ilə bağlı qısa məlumat verəsiniz</translation>
    </message>
    <message>
        <source>Content：</source>
        <translation>Məzmun :</translation>
    </message>
    <message>
        <source>Do not fill in multiple issues in one feedback</source>
        <translation>Bir rəyə çox sayda problemləri daxil etməyin</translation>
    </message>
    <message>
        <source>Do not fill in multiple requirements in one feedback</source>
        <translation>Bir rəydə çox sayda tələblər yerləşdirməyin</translation>
    </message>
    <message>
        <source>Email：</source>
        <translation>E-poçt :</translation>
    </message>
    <message>
        <source>Please enter your email</source>
        <translation>Lütfən e-poçt ünvanınızı daxil edin</translation>
    </message>
    <message>
        <source>System Version:</source>
        <translation>Sistemin versiyası</translation>
    </message>
    <message>
        <source>Device Info：</source>
        <translation>Cihaz haqqında məlumat :</translation>
    </message>
    <message>
        <source>Upload &lt;a href=&apos;home://sysinfo&apos;&gt;device information&lt;/a&gt;</source>
        <translation>&lt;a href=&apos;home://sysinfo&apos;&gt;Cihaz məumatlarını&lt;/a&gt; yükləyin</translation>
    </message>
    <message>
        <source>Screenshots：</source>
        <translation>Ekran şəkilləri :</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>Şəkil faylları</translation>
    </message>
    <message>
        <source>Drag and drop files or click buttons to add pictures, up to three</source>
        <translation>Sürüşdürüb atmaqla və ya düymələrə vurmaqla şəkillər (3-ə qədər) əlavə edin,</translation>
    </message>
    <message>
        <source>Are you sure you want to exit the feedback submission?</source>
        <translation>Rəy göndərilməsindən çıxmaq istədiyinizə əminsiniz?</translation>
    </message>
    <message>
        <source>The feedback content will not be saved.</source>
        <translation>Rəyin məzmunu saxlanılmayacaq.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Ləğv edin</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Çıxın</translation>
    </message>
    <message>
        <source>Submit</source>
        <translation>Göndərin</translation>
    </message>
    <message>
        <source>Unable to submit feedback.</source>
        <translation>Rəyi göndərmək mümkün olmadı.</translation>
    </message>
    <message>
        <source>Please provide the title and content of your feedback.</source>
        <translation>Lütfən, rəyinizin başlığını və məzmununu təqdim edin.</translation>
    </message>
    <message>
        <source>Please provide the title of your feedback.</source>
        <translation>Rəyinizin başlığını təqdim etməniz xahiş olunur.</translation>
    </message>
    <message>
        <source>Please provide the content of your feedback.</source>
        <translation>Rəyinizin məzmununu təqdim etməniz xahiş olunur.</translation>
    </message>
    <message>
        <source>Incorrect email address entered.</source>
        <translation>Səhv e-poçt ünvanı daxil edilib.</translation>
    </message>
    <message>
        <source>Device Information</source>
        <translation>Cihaz haqqında məlumat</translation>
    </message>
</context>
<context>
    <name>TabButton</name>
    <message>
        <source>Feedback Hub</source>
        <translation>Geri əlaqə mərkəzi</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Mənim rəylərim</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Seçilmişlər</translation>
    </message>
    <message>
        <source>My Urged</source>
        <translation>İstədiklərim</translation>
    </message>
</context>
</TS>